@@ -59,21 +59,36 @@ correction_factors <- get_correction_factors(angle_counts,
 
 
 ###################################################
-### code chunk number 6: options
+### code chunk number 6: comparison
+###################################################
+m <- merge(angle_counts[TRUE, c("tnr", "enr", "bnr",
+                                "kf2", "pk", "stp")],
+           correction_factors)
+rdiff <- fritools::relative_difference(m[["correction_factor"]], m[["kf2"]])
+works <- RUnit::checkTrue(all(abs(rdiff) < 0.001))
+if (works) {
+    print("Concurs with tests in runit/")
+} else {
+    stop("Break vignette.")
+}
+
+
+###################################################
+### code chunk number 7: options
 ###################################################
 set_options()
 str(getOption("treePlotArea"))
 
 
 ###################################################
-### code chunk number 7: data_rename
+### code chunk number 8: data_rename
 ###################################################
 names(angle_counts) <- toupper(names(angle_counts))
 names(boundaries) <- toupper(names(boundaries))
 
 
 ###################################################
-### code chunk number 8: data_options
+### code chunk number 9: data_options
 ###################################################
 option_list <- sapply(get_defaults(), function(x) lapply(x, toupper))
 set_options(angle_counts = option_list[["angle_counts"]],
@@ -81,7 +96,7 @@ set_options(angle_counts = option_list[["angle_counts"]],
 
 
 ###################################################
-### code chunk number 9: data_runit
+### code chunk number 10: data_runit
 ###################################################
 correction_factors_upper <- get_correction_factors(angle_counts,
                                                    boundaries,
@@ -91,7 +106,7 @@ RUnit::checkEquals(correction_factors_upper, correction_factors,
 
 
 ###################################################
-### code chunk number 10: ptpa_1
+### code chunk number 11: ptpa_1
 ###################################################
 cf <- plot_tree_plot_area(angle_counts = angle_counts,
                           boundaries = boundaries,
@@ -100,7 +115,7 @@ cf <- plot_tree_plot_area(angle_counts = angle_counts,
 
 
 ###################################################
-### code chunk number 11: ptpa_4
+### code chunk number 12: ptpa_4
 ###################################################
 cf <- plot_tree_plot_area(angle_counts = angle_counts,
                           boundaries = boundaries,
